FileWriteOption

Struct FileWriteOption 

pub struct FileWriteOption(/* private fields */);

Implementations

Source

impl FileWriteOption

pub const fn from(val: u32) -> Self

Creates a FileWriteOption from the underlying base type u32

pub const fn contains(self, other: Self) -> bool

Checks if the provided FileWriteOption has all of the set bits in other are set in self

pub const fn intersects(self, other: Self) -> bool

Checks if the provided FileWriteOption has any common bits with other

pub const fn get(self) -> u32

Returns the value as the underlying type

pub const fn None() -> Self

Returns a FileWriteOption where only the bit for None is set

pub const fn Flush() -> Self

Returns a FileWriteOption where only the bit for Flush is set